summaryrefslogtreecommitdiffstats
path: root/kresources/kolab/kabc
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-16 09:59:50 -0600
commit9cc13dcbb01a96c9e60a07ca63c61d24b374f50d (patch)
treeab537a329b9613e11dce8195761f93ffe82aed24 /kresources/kolab/kabc
parent3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12 (diff)
downloadtdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.tar.gz
tdepim-9cc13dcbb01a96c9e60a07ca63c61d24b374f50d.zip
Revert "Rename a number of old tq methods that are no longer tq specific"
This reverts commit 3ca10fd9a2dc631429d3b5d5c5e42a7d211d5a12.
Diffstat (limited to 'kresources/kolab/kabc')
-rw-r--r--kresources/kolab/kabc/contact.cpp18
-rw-r--r--kresources/kolab/kabc/contact.h4
2 files changed, 11 insertions, 11 deletions
diff --git a/kresources/kolab/kabc/contact.h b/kresources/kolab/kabc/contact.h
index 6e0de80b..60c39933 100644
--- a/kresources/kolab/kabc/contact.h
+++ b/kresources/kolab/kabc/contact.h
@@ -154,8 +154,8 @@ public:
TQString soundAttachmentName() const { return mSoundAttachmentName; }
TQByteArray sound() const { return mSound; }
- void setChildren( const TQString& children );
- TQString children() const;
+ void setChildren( const TQString& tqchildren );
+ TQString tqchildren() const;
void setGender( const TQString& gender );
TQString gender() const;
diff --git a/kresources/kolab/kabc/contact.cpp b/kresources/kolab/kabc/contact.cpp
index 79609902..7a26f62f 100644
--- a/kresources/kolab/kabc/contact.cpp
+++ b/kresources/kolab/kabc/contact.cpp
@@ -293,12 +293,12 @@ TQDate Contact::anniversary() const
return mAnniversary;
}
-void Contact::setChildren( const TQString& children )
+void Contact::setChildren( const TQString& tqchildren )
{
- mChildren = children;
+ mChildren = tqchildren;
}
-TQString Contact::children() const
+TQString Contact::tqchildren() const
{
return mChildren;
}
@@ -487,7 +487,7 @@ void Contact::saveCustomAttributes( TQDomElement& element ) const
writeString( element, (*it).name, (*it).value );
} else {
// skip writing the freebusyurl as it is a hack we need to remove eventually
- if ( (*it).name == TQString::fromLatin1( "FreeBusyURL" ) ) {
+ if ( (*it).name == TQString::tqfromLatin1( "FreeBusyURL" ) ) {
continue;
}
@@ -619,7 +619,7 @@ bool Contact::loadAttribute( TQDomElement& element )
}
break;
case 'c':
- if ( tagName == "children" ) {
+ if ( tagName == "tqchildren" ) {
setChildren( element.text() );
return true;
}
@@ -798,7 +798,7 @@ bool Contact::saveAttributes( TQDomElement& element ) const
writeString( element, "x-logo", mLogoAttachmentName );
if ( !sound().isNull() )
writeString( element, "x-sound", mSoundAttachmentName );
- writeString( element, "children", children() );
+ writeString( element, "tqchildren", tqchildren() );
writeString( element, "gender", gender() );
writeString( element, "language", language() );
savePhoneAttributes( element );
@@ -1110,7 +1110,7 @@ void Contact::setFields( const KABC::Addressee* addressee )
// (includes e.g. crypto settings, and extra im addresses)
TQStringList knownCustoms;
for ( const char** p = s_knownCustomFields; *p; ++p )
- knownCustoms << TQString::fromLatin1( *p );
+ knownCustoms << TQString::tqfromLatin1( *p );
TQStringList customs = addressee->customs();
for( TQStringList::Iterator it = customs.begin(); it != customs.end(); ++it ) {
// KABC::Addressee doesn't offer a real way to iterate over customs, other than splitting strings ourselves
@@ -1146,7 +1146,7 @@ void Contact::setFields( const KABC::Addressee* addressee )
// mailer, timezone, productId, sortString, agent, rfc2426 name()
// Things KAddressBook can't handle, so they are saved as unhandled tags:
// initials, children, gender, language
}
// The loading is: xml -> Contact -> addressee, this is the second part
@@ -1253,7 +1253,7 @@ void Contact::saveTo( KABC::Addressee* addressee )
}
for( TQValueList<Custom>::ConstIterator it = mCustomList.begin(); it != mCustomList.end(); ++it ) {
- TQString app = (*it).app.isEmpty() ? TQString::fromLatin1( "KADDRESSBOOK" ) : (*it).app;
+ TQString app = (*it).app.isEmpty() ? TQString::tqfromLatin1( "KADDRESSBOOK" ) : (*it).app;
addressee->insertCustom( app, (*it).name, (*it).value );
}
//kdDebug(5006) << addressee->customs() << endl;
@@ -1146,7 +1146,7 @@ void Contact::setFields( const KABC::Addressee* addressee )
// mailer, timezone, productId, sortString, agent, rfc2426 name()
// Things KAddressBook can't handle, so they are saved as unhandled tags:
- // initials, children, gender, language
+ // initials, tqchildren, gender, language
}
// The loading is: xml -> Contact -> addressee, this is the second part